# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.dataframer.evaluations import chat_send_message_params
from ....types.dataframer.evaluations.chat_get_history_response import ChatGetHistoryResponse
from ....types.dataframer.evaluations.chat_send_message_response import ChatSendMessageResponse

__all__ = ["ChatResource", "AsyncChatResource"]


class ChatResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return ChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return ChatResourceWithStreamingResponse(self)

    def get_history(
        self,
        evaluation_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ChatGetHistoryResponse:
        """
        Get chat history for an evaluation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_id` but received {evaluation_id!r}")
        return self._get(
            f"/api/dataframer/evaluations/{evaluation_id}/chat/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChatGetHistoryResponse,
        )

    def send_message(
        self,
        evaluation_id: str,
        *,
        user_message: str,
        chat_model: Literal[
            "anthropic/claude-sonnet-4-5", "anthropic/claude-sonnet-4-5-thinking", "anthropic/claude-haiku-4-5"
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ChatSendMessageResponse:
        """
        Send a natural language query about evaluation results and get AI-powered
        insights.

        The chat process:

        1. Retrieves generated samples from the run
        2. Includes previous chat history for context
        3. Sends query to AI model with evaluation context
        4. Returns AI response with insights
        5. Saves conversation for future reference

        **Use Cases**:

        - Ask why samples scored lower
        - Understand conformance issues
        - Get recommendations for improvement
        - Explore evaluation results interactively

        Args:
          user_message: Your question or message about the evaluation results

          chat_model: AI model to use for chat (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_id` but received {evaluation_id!r}")
        return self._post(
            f"/api/dataframer/evaluations/{evaluation_id}/chat/",
            body=maybe_transform(
                {
                    "user_message": user_message,
                    "chat_model": chat_model,
                },
                chat_send_message_params.ChatSendMessageParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChatSendMessageResponse,
        )


class AsyncChatResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncChatResourceWithStreamingResponse(self)

    async def get_history(
        self,
        evaluation_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ChatGetHistoryResponse:
        """
        Get chat history for an evaluation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_id` but received {evaluation_id!r}")
        return await self._get(
            f"/api/dataframer/evaluations/{evaluation_id}/chat/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChatGetHistoryResponse,
        )

    async def send_message(
        self,
        evaluation_id: str,
        *,
        user_message: str,
        chat_model: Literal[
            "anthropic/claude-sonnet-4-5", "anthropic/claude-sonnet-4-5-thinking", "anthropic/claude-haiku-4-5"
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ChatSendMessageResponse:
        """
        Send a natural language query about evaluation results and get AI-powered
        insights.

        The chat process:

        1. Retrieves generated samples from the run
        2. Includes previous chat history for context
        3. Sends query to AI model with evaluation context
        4. Returns AI response with insights
        5. Saves conversation for future reference

        **Use Cases**:

        - Ask why samples scored lower
        - Understand conformance issues
        - Get recommendations for improvement
        - Explore evaluation results interactively

        Args:
          user_message: Your question or message about the evaluation results

          chat_model: AI model to use for chat (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_id:
            raise ValueError(f"Expected a non-empty value for `evaluation_id` but received {evaluation_id!r}")
        return await self._post(
            f"/api/dataframer/evaluations/{evaluation_id}/chat/",
            body=await async_maybe_transform(
                {
                    "user_message": user_message,
                    "chat_model": chat_model,
                },
                chat_send_message_params.ChatSendMessageParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ChatSendMessageResponse,
        )


class ChatResourceWithRawResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.get_history = to_raw_response_wrapper(
            chat.get_history,
        )
        self.send_message = to_raw_response_wrapper(
            chat.send_message,
        )


class AsyncChatResourceWithRawResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.get_history = async_to_raw_response_wrapper(
            chat.get_history,
        )
        self.send_message = async_to_raw_response_wrapper(
            chat.send_message,
        )


class ChatResourceWithStreamingResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.get_history = to_streamed_response_wrapper(
            chat.get_history,
        )
        self.send_message = to_streamed_response_wrapper(
            chat.send_message,
        )


class AsyncChatResourceWithStreamingResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.get_history = async_to_streamed_response_wrapper(
            chat.get_history,
        )
        self.send_message = async_to_streamed_response_wrapper(
            chat.send_message,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.dataframer import analyze_create_params
from ...types.dataframer.analyze_create_response import AnalyzeCreateResponse
from ...types.dataframer.analyze_get_status_response import AnalyzeGetStatusResponse

__all__ = ["AnalyzeResource", "AsyncAnalyzeResource"]


class AnalyzeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AnalyzeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AnalyzeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AnalyzeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AnalyzeResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        dataset_id: str,
        name: str,
        analysis_model_name: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        description: str | Omit = omit,
        extrapolate_axes: bool | Omit = omit,
        extrapolate_values: bool | Omit = omit,
        generate_distributions: bool | Omit = omit,
        generation_objectives: str | Omit = omit,
        use_truncation: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnalyzeCreateResponse:
        """
        Analyze dataset files using AI to understand the data structure and patterns,
        then create a new spec with version 1 based on the analysis.

        The analysis process:

        1. Reads all files from the dataset
        2. Analyzes data structure, patterns, and relationships
        3. Generates spec configuration for synthetic data generation
        4. Creates spec with version 1 containing the analysis results

        Args:
          dataset_id: ID of the dataset to analyze

          name: Name for the new spec to be created

          analysis_model_name: AI model to use for analysis

          description: Description of the spec

          extrapolate_axes: Extrapolate to new axes/dimensions

          extrapolate_values: Extrapolate new values beyond existing data ranges

          generate_distributions: Generate statistical distributions from the data

          generation_objectives: Custom objectives or instructions for data generation

          use_truncation: Apply truncation to limit value ranges

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/dataframer/analyze/",
            body=maybe_transform(
                {
                    "dataset_id": dataset_id,
                    "name": name,
                    "analysis_model_name": analysis_model_name,
                    "description": description,
                    "extrapolate_axes": extrapolate_axes,
                    "extrapolate_values": extrapolate_values,
                    "generate_distributions": generate_distributions,
                    "generation_objectives": generation_objectives,
                    "use_truncation": use_truncation,
                },
                analyze_create_params.AnalyzeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AnalyzeCreateResponse,
        )

    def get_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnalyzeGetStatusResponse:
        """
        Get analysis status from external service (client-side polling)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return self._get(
            f"/api/dataframer/analyze/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AnalyzeGetStatusResponse,
        )


class AsyncAnalyzeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAnalyzeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncAnalyzeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAnalyzeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncAnalyzeResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        dataset_id: str,
        name: str,
        analysis_model_name: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        description: str | Omit = omit,
        extrapolate_axes: bool | Omit = omit,
        extrapolate_values: bool | Omit = omit,
        generate_distributions: bool | Omit = omit,
        generation_objectives: str | Omit = omit,
        use_truncation: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnalyzeCreateResponse:
        """
        Analyze dataset files using AI to understand the data structure and patterns,
        then create a new spec with version 1 based on the analysis.

        The analysis process:

        1. Reads all files from the dataset
        2. Analyzes data structure, patterns, and relationships
        3. Generates spec configuration for synthetic data generation
        4. Creates spec with version 1 containing the analysis results

        Args:
          dataset_id: ID of the dataset to analyze

          name: Name for the new spec to be created

          analysis_model_name: AI model to use for analysis

          description: Description of the spec

          extrapolate_axes: Extrapolate to new axes/dimensions

          extrapolate_values: Extrapolate new values beyond existing data ranges

          generate_distributions: Generate statistical distributions from the data

          generation_objectives: Custom objectives or instructions for data generation

          use_truncation: Apply truncation to limit value ranges

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/dataframer/analyze/",
            body=await async_maybe_transform(
                {
                    "dataset_id": dataset_id,
                    "name": name,
                    "analysis_model_name": analysis_model_name,
                    "description": description,
                    "extrapolate_axes": extrapolate_axes,
                    "extrapolate_values": extrapolate_values,
                    "generate_distributions": generate_distributions,
                    "generation_objectives": generation_objectives,
                    "use_truncation": use_truncation,
                },
                analyze_create_params.AnalyzeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AnalyzeCreateResponse,
        )

    async def get_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AnalyzeGetStatusResponse:
        """
        Get analysis status from external service (client-side polling)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return await self._get(
            f"/api/dataframer/analyze/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AnalyzeGetStatusResponse,
        )


class AnalyzeResourceWithRawResponse:
    def __init__(self, analyze: AnalyzeResource) -> None:
        self._analyze = analyze

        self.create = to_raw_response_wrapper(
            analyze.create,
        )
        self.get_status = to_raw_response_wrapper(
            analyze.get_status,
        )


class AsyncAnalyzeResourceWithRawResponse:
    def __init__(self, analyze: AsyncAnalyzeResource) -> None:
        self._analyze = analyze

        self.create = async_to_raw_response_wrapper(
            analyze.create,
        )
        self.get_status = async_to_raw_response_wrapper(
            analyze.get_status,
        )


class AnalyzeResourceWithStreamingResponse:
    def __init__(self, analyze: AnalyzeResource) -> None:
        self._analyze = analyze

        self.create = to_streamed_response_wrapper(
            analyze.create,
        )
        self.get_status = to_streamed_response_wrapper(
            analyze.get_status,
        )


class AsyncAnalyzeResourceWithStreamingResponse:
    def __init__(self, analyze: AsyncAnalyzeResource) -> None:
        self._analyze = analyze

        self.create = async_to_streamed_response_wrapper(
            analyze.create,
        )
        self.get_status = async_to_streamed_response_wrapper(
            analyze.get_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .folder import Folder

__all__ = ["DatasetListFoldersResponse"]

DatasetListFoldersResponse: TypeAlias = List[Folder]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from dataframer import Dataframer, AsyncDataframer
from tests.utils import assert_matches_type
from dataframer._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)
from dataframer.types.dataframer.runs import (
    GeneratedFileListResponse,
    GeneratedFileDownloadResponse,
    GeneratedFileGetContentResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestGeneratedFiles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Dataframer) -> None:
        generated_file = client.dataframer.runs.generated_files.list(
            "run_id",
        )
        assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Dataframer) -> None:
        response = client.dataframer.runs.generated_files.with_raw_response.list(
            "run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = response.parse()
        assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Dataframer) -> None:
        with client.dataframer.runs.generated_files.with_streaming_response.list(
            "run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = response.parse()
            assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_download(self, client: Dataframer) -> None:
        generated_file = client.dataframer.runs.generated_files.download(
            file_id="file_id",
            run_id="run_id",
        )
        assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_download(self, client: Dataframer) -> None:
        response = client.dataframer.runs.generated_files.with_raw_response.download(
            file_id="file_id",
            run_id="run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = response.parse()
        assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_download(self, client: Dataframer) -> None:
        with client.dataframer.runs.generated_files.with_streaming_response.download(
            file_id="file_id",
            run_id="run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = response.parse()
            assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_download(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.download(
                file_id="file_id",
                run_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.download(
                file_id="",
                run_id="run_id",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_download_all(self, client: Dataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        generated_file = client.dataframer.runs.generated_files.download_all(
            "run_id",
        )
        assert generated_file.is_closed
        assert generated_file.json() == {"foo": "bar"}
        assert cast(Any, generated_file.is_closed) is True
        assert isinstance(generated_file, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_download_all(self, client: Dataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        generated_file = client.dataframer.runs.generated_files.with_raw_response.download_all(
            "run_id",
        )

        assert generated_file.is_closed is True
        assert generated_file.http_request.headers.get("X-Stainless-Lang") == "python"
        assert generated_file.json() == {"foo": "bar"}
        assert isinstance(generated_file, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_download_all(self, client: Dataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        with client.dataframer.runs.generated_files.with_streaming_response.download_all(
            "run_id",
        ) as generated_file:
            assert not generated_file.is_closed
            assert generated_file.http_request.headers.get("X-Stainless-Lang") == "python"

            assert generated_file.json() == {"foo": "bar"}
            assert cast(Any, generated_file.is_closed) is True
            assert isinstance(generated_file, StreamedBinaryAPIResponse)

        assert cast(Any, generated_file.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_path_params_download_all(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.download_all(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_content(self, client: Dataframer) -> None:
        generated_file = client.dataframer.runs.generated_files.get_content(
            file_id="file_id",
            run_id="run_id",
        )
        assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_content(self, client: Dataframer) -> None:
        response = client.dataframer.runs.generated_files.with_raw_response.get_content(
            file_id="file_id",
            run_id="run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = response.parse()
        assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_content(self, client: Dataframer) -> None:
        with client.dataframer.runs.generated_files.with_streaming_response.get_content(
            file_id="file_id",
            run_id="run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = response.parse()
            assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_content(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.get_content(
                file_id="file_id",
                run_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            client.dataframer.runs.generated_files.with_raw_response.get_content(
                file_id="",
                run_id="run_id",
            )


class TestAsyncGeneratedFiles:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncDataframer) -> None:
        generated_file = await async_client.dataframer.runs.generated_files.list(
            "run_id",
        )
        assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.runs.generated_files.with_raw_response.list(
            "run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = await response.parse()
        assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.runs.generated_files.with_streaming_response.list(
            "run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = await response.parse()
            assert_matches_type(GeneratedFileListResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_download(self, async_client: AsyncDataframer) -> None:
        generated_file = await async_client.dataframer.runs.generated_files.download(
            file_id="file_id",
            run_id="run_id",
        )
        assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_download(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.runs.generated_files.with_raw_response.download(
            file_id="file_id",
            run_id="run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = await response.parse()
        assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_download(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.runs.generated_files.with_streaming_response.download(
            file_id="file_id",
            run_id="run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = await response.parse()
            assert_matches_type(GeneratedFileDownloadResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_download(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.download(
                file_id="file_id",
                run_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.download(
                file_id="",
                run_id="run_id",
            )

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_download_all(self, async_client: AsyncDataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        generated_file = await async_client.dataframer.runs.generated_files.download_all(
            "run_id",
        )
        assert generated_file.is_closed
        assert await generated_file.json() == {"foo": "bar"}
        assert cast(Any, generated_file.is_closed) is True
        assert isinstance(generated_file, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_download_all(self, async_client: AsyncDataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )

        generated_file = await async_client.dataframer.runs.generated_files.with_raw_response.download_all(
            "run_id",
        )

        assert generated_file.is_closed is True
        assert generated_file.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await generated_file.json() == {"foo": "bar"}
        assert isinstance(generated_file, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_download_all(self, async_client: AsyncDataframer, respx_mock: MockRouter) -> None:
        respx_mock.get("/api/dataframer/runs/run_id/generated-files/download-all/").mock(
            return_value=httpx.Response(200, json={"foo": "bar"})
        )
        async with async_client.dataframer.runs.generated_files.with_streaming_response.download_all(
            "run_id",
        ) as generated_file:
            assert not generated_file.is_closed
            assert generated_file.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await generated_file.json() == {"foo": "bar"}
            assert cast(Any, generated_file.is_closed) is True
            assert isinstance(generated_file, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, generated_file.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_path_params_download_all(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.download_all(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_content(self, async_client: AsyncDataframer) -> None:
        generated_file = await async_client.dataframer.runs.generated_files.get_content(
            file_id="file_id",
            run_id="run_id",
        )
        assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_content(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.runs.generated_files.with_raw_response.get_content(
            file_id="file_id",
            run_id="run_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        generated_file = await response.parse()
        assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_content(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.runs.generated_files.with_streaming_response.get_content(
            file_id="file_id",
            run_id="run_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            generated_file = await response.parse()
            assert_matches_type(GeneratedFileGetContentResponse, generated_file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_content(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.get_content(
                file_id="file_id",
                run_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            await async_client.dataframer.runs.generated_files.with_raw_response.get_content(
                file_id="",
                run_id="run_id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.dataframer.red_team_create_task_response import RedTeamCreateTaskResponse
from ...types.dataframer.red_team_retrieve_status_response import RedTeamRetrieveStatusResponse

__all__ = ["RedTeamResource", "AsyncRedTeamResource"]


class RedTeamResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RedTeamResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return RedTeamResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RedTeamResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return RedTeamResourceWithStreamingResponse(self)

    def create_task(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RedTeamCreateTaskResponse:
        """
        Expected payload: { "domain_description": "string", "num_behaviors": int,
        "num_prompts": int, "model_name": "string" }
        """
        return self._post(
            "/api/dataframer/red-team/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RedTeamCreateTaskResponse,
        )

    def retrieve_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RedTeamRetrieveStatusResponse:
        """
        Get the status of a red teaming task.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return self._get(
            f"/api/dataframer/red-team/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RedTeamRetrieveStatusResponse,
        )


class AsyncRedTeamResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRedTeamResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncRedTeamResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRedTeamResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncRedTeamResourceWithStreamingResponse(self)

    async def create_task(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RedTeamCreateTaskResponse:
        """
        Expected payload: { "domain_description": "string", "num_behaviors": int,
        "num_prompts": int, "model_name": "string" }
        """
        return await self._post(
            "/api/dataframer/red-team/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RedTeamCreateTaskResponse,
        )

    async def retrieve_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RedTeamRetrieveStatusResponse:
        """
        Get the status of a red teaming task.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return await self._get(
            f"/api/dataframer/red-team/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RedTeamRetrieveStatusResponse,
        )


class RedTeamResourceWithRawResponse:
    def __init__(self, red_team: RedTeamResource) -> None:
        self._red_team = red_team

        self.create_task = to_raw_response_wrapper(
            red_team.create_task,
        )
        self.retrieve_status = to_raw_response_wrapper(
            red_team.retrieve_status,
        )


class AsyncRedTeamResourceWithRawResponse:
    def __init__(self, red_team: AsyncRedTeamResource) -> None:
        self._red_team = red_team

        self.create_task = async_to_raw_response_wrapper(
            red_team.create_task,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            red_team.retrieve_status,
        )


class RedTeamResourceWithStreamingResponse:
    def __init__(self, red_team: RedTeamResource) -> None:
        self._red_team = red_team

        self.create_task = to_streamed_response_wrapper(
            red_team.create_task,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            red_team.retrieve_status,
        )


class AsyncRedTeamResourceWithStreamingResponse:
    def __init__(self, red_team: AsyncRedTeamResource) -> None:
        self._red_team = red_team

        self.create_task = async_to_streamed_response_wrapper(
            red_team.create_task,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            red_team.retrieve_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["HumanLabelRetrieveResponse"]


class HumanLabelRetrieveResponse(BaseModel):
    file_identifier: str
    """Identifier for the file (filename or folder/filename path)"""

    labels: Dict[str, object]
    """JSON object mapping label keys to values"""

    run_id: str

    id: Optional[str] = None

    company_id: Optional[str] = None

    created_at: Optional[datetime] = None

    created_by: Optional[int] = None

    created_by_name: Optional[str] = None

    sample_identifier: Optional[str] = None
    """Optional: row identifier for structured files (e.g., "sample_0")"""

    updated_at: Optional[datetime] = None

    updated_by: Optional[int] = None

    updated_by_name: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, TypedDict

__all__ = ["SpecUpdateParams"]


class SpecUpdateParams(TypedDict, total=False):
    config_yaml: Required[str]
    """YAML configuration for the spec (required)"""

    description: str
    """Update the spec description (optional)"""

    name: str
    """Update the spec name (optional)"""

    orig_results_yaml: str
    """Original results YAML (optional)"""

    results_yaml: str
    """Results YAML from analysis (optional)"""

    runtime_params: Dict[str, object]
    """Runtime parameters for generation (optional)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["EvaluationCreateParams"]


class EvaluationCreateParams(TypedDict, total=False):
    run_id: Required[str]
    """ID of the completed run to evaluate"""

    evaluation_model: Literal[
        "anthropic/claude-sonnet-4-5", "anthropic/claude-sonnet-4-5-thinking", "anthropic/claude-haiku-4-5"
    ]
    """AI model to use for evaluation (optional)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .specs import (
    SpecsResource,
    AsyncSpecsResource,
    SpecsResourceWithRawResponse,
    AsyncSpecsResourceWithRawResponse,
    SpecsResourceWithStreamingResponse,
    AsyncSpecsResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)

__all__ = [
    "VersionsResource",
    "AsyncVersionsResource",
    "VersionsResourceWithRawResponse",
    "AsyncVersionsResourceWithRawResponse",
    "VersionsResourceWithStreamingResponse",
    "AsyncVersionsResourceWithStreamingResponse",
    "SpecsResource",
    "AsyncSpecsResource",
    "SpecsResourceWithRawResponse",
    "AsyncSpecsResourceWithRawResponse",
    "SpecsResourceWithStreamingResponse",
    "AsyncSpecsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["ChatSendMessageResponse"]


class ChatSendMessageResponse(BaseModel):
    assistant_message: str
    """Assistant's response"""

    evaluation_id: str

    user_message: str
    """User's question/query"""

    id: Optional[str] = None

    created_at: Optional[datetime] = None

    user: Optional[int] = None

    user_email: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict

import httpx

from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.dataframer import spec_create_params, spec_update_params
from ....types.dataframer.spec_list_response import SpecListResponse
from ....types.dataframer.spec_create_response import SpecCreateResponse
from ....types.dataframer.spec_update_response import SpecUpdateResponse
from ....types.dataframer.spec_retrieve_response import SpecRetrieveResponse

__all__ = ["SpecsResource", "AsyncSpecsResource"]


class SpecsResource(SyncAPIResource):
    @cached_property
    def versions(self) -> VersionsResource:
        return VersionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> SpecsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SpecsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SpecsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return SpecsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        datasets_id: str,
        name: str,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecCreateResponse:
        """
        Create a new spec manually without using the analyze endpoint.

        **Note**: Most users should use `/api/dataframer/analyze/` instead, which
        automatically analyzes a dataset and creates a spec with proper configuration.

        This endpoint allows manual spec creation for advanced use cases where you want
        to define the spec structure yourself.

        Args:
          datasets_id: UUID of the dataset this spec is based on

          name: Unique name for the spec (within dataset and company)

          description: Optional description of the spec

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/dataframer/specs/",
            body=maybe_transform(
                {
                    "datasets_id": datasets_id,
                    "name": name,
                    "description": description,
                },
                spec_create_params.SpecCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecCreateResponse,
        )

    def retrieve(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecRetrieveResponse:
        """
        Get a specific spec, optionally with deletion impact info

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return self._get(
            f"/api/dataframer/specs/{spec_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecRetrieveResponse,
        )

    def update(
        self,
        spec_id: str,
        *,
        config_yaml: str,
        description: str | Omit = omit,
        name: str | Omit = omit,
        orig_results_yaml: str | Omit = omit,
        results_yaml: str | Omit = omit,
        runtime_params: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecUpdateResponse:
        """
        Update a spec by creating a new version with modified YAML configuration.

        Each update creates a new version (up to 30 versions per spec). You can update:

        - config_yaml: The spec configuration (required)
        - results_yaml: Results from analysis (optional)
        - orig_results_yaml: Original analysis results (optional)
        - runtime_params: Runtime parameters for generation (optional)
        - name: Update the spec name (optional)
        - description: Update the spec description (optional)

        The config_yaml contains the data property variations, distributions, and
        generation requirements.

        Args:
          config_yaml: YAML configuration for the spec (required)

          description: Update the spec description (optional)

          name: Update the spec name (optional)

          orig_results_yaml: Original results YAML (optional)

          results_yaml: Results YAML from analysis (optional)

          runtime_params: Runtime parameters for generation (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return self._put(
            f"/api/dataframer/specs/{spec_id}/",
            body=maybe_transform(
                {
                    "config_yaml": config_yaml,
                    "description": description,
                    "name": name,
                    "orig_results_yaml": orig_results_yaml,
                    "results_yaml": results_yaml,
                    "runtime_params": runtime_params,
                },
                spec_update_params.SpecUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecUpdateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecListResponse:
        """Get all specs for the user's company"""
        return self._get(
            "/api/dataframer/specs/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecListResponse,
        )

    def delete(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a spec and clean up associated runs and S3 files

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/api/dataframer/specs/{spec_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSpecsResource(AsyncAPIResource):
    @cached_property
    def versions(self) -> AsyncVersionsResource:
        return AsyncVersionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncSpecsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSpecsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSpecsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncSpecsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        datasets_id: str,
        name: str,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecCreateResponse:
        """
        Create a new spec manually without using the analyze endpoint.

        **Note**: Most users should use `/api/dataframer/analyze/` instead, which
        automatically analyzes a dataset and creates a spec with proper configuration.

        This endpoint allows manual spec creation for advanced use cases where you want
        to define the spec structure yourself.

        Args:
          datasets_id: UUID of the dataset this spec is based on

          name: Unique name for the spec (within dataset and company)

          description: Optional description of the spec

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/dataframer/specs/",
            body=await async_maybe_transform(
                {
                    "datasets_id": datasets_id,
                    "name": name,
                    "description": description,
                },
                spec_create_params.SpecCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecCreateResponse,
        )

    async def retrieve(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecRetrieveResponse:
        """
        Get a specific spec, optionally with deletion impact info

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return await self._get(
            f"/api/dataframer/specs/{spec_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecRetrieveResponse,
        )

    async def update(
        self,
        spec_id: str,
        *,
        config_yaml: str,
        description: str | Omit = omit,
        name: str | Omit = omit,
        orig_results_yaml: str | Omit = omit,
        results_yaml: str | Omit = omit,
        runtime_params: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecUpdateResponse:
        """
        Update a spec by creating a new version with modified YAML configuration.

        Each update creates a new version (up to 30 versions per spec). You can update:

        - config_yaml: The spec configuration (required)
        - results_yaml: Results from analysis (optional)
        - orig_results_yaml: Original analysis results (optional)
        - runtime_params: Runtime parameters for generation (optional)
        - name: Update the spec name (optional)
        - description: Update the spec description (optional)

        The config_yaml contains the data property variations, distributions, and
        generation requirements.

        Args:
          config_yaml: YAML configuration for the spec (required)

          description: Update the spec description (optional)

          name: Update the spec name (optional)

          orig_results_yaml: Original results YAML (optional)

          results_yaml: Results YAML from analysis (optional)

          runtime_params: Runtime parameters for generation (optional)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return await self._put(
            f"/api/dataframer/specs/{spec_id}/",
            body=await async_maybe_transform(
                {
                    "config_yaml": config_yaml,
                    "description": description,
                    "name": name,
                    "orig_results_yaml": orig_results_yaml,
                    "results_yaml": results_yaml,
                    "runtime_params": runtime_params,
                },
                spec_update_params.SpecUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecUpdateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecListResponse:
        """Get all specs for the user's company"""
        return await self._get(
            "/api/dataframer/specs/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecListResponse,
        )

    async def delete(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a spec and clean up associated runs and S3 files

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/api/dataframer/specs/{spec_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SpecsResourceWithRawResponse:
    def __init__(self, specs: SpecsResource) -> None:
        self._specs = specs

        self.create = to_raw_response_wrapper(
            specs.create,
        )
        self.retrieve = to_raw_response_wrapper(
            specs.retrieve,
        )
        self.update = to_raw_response_wrapper(
            specs.update,
        )
        self.list = to_raw_response_wrapper(
            specs.list,
        )
        self.delete = to_raw_response_wrapper(
            specs.delete,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithRawResponse:
        return VersionsResourceWithRawResponse(self._specs.versions)


class AsyncSpecsResourceWithRawResponse:
    def __init__(self, specs: AsyncSpecsResource) -> None:
        self._specs = specs

        self.create = async_to_raw_response_wrapper(
            specs.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            specs.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            specs.update,
        )
        self.list = async_to_raw_response_wrapper(
            specs.list,
        )
        self.delete = async_to_raw_response_wrapper(
            specs.delete,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithRawResponse:
        return AsyncVersionsResourceWithRawResponse(self._specs.versions)


class SpecsResourceWithStreamingResponse:
    def __init__(self, specs: SpecsResource) -> None:
        self._specs = specs

        self.create = to_streamed_response_wrapper(
            specs.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            specs.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            specs.update,
        )
        self.list = to_streamed_response_wrapper(
            specs.list,
        )
        self.delete = to_streamed_response_wrapper(
            specs.delete,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithStreamingResponse:
        return VersionsResourceWithStreamingResponse(self._specs.versions)


class AsyncSpecsResourceWithStreamingResponse:
    def __init__(self, specs: AsyncSpecsResource) -> None:
        self._specs = specs

        self.create = async_to_streamed_response_wrapper(
            specs.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            specs.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            specs.update,
        )
        self.list = async_to_streamed_response_wrapper(
            specs.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            specs.delete,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithStreamingResponse:
        return AsyncVersionsResourceWithStreamingResponse(self._specs.versions)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .file import File as File
from .folder import Folder as Folder
from .run_create_params import RunCreateParams as RunCreateParams
from .run_list_response import RunListResponse as RunListResponse
from .file_list_response import FileListResponse as FileListResponse
from .spec_create_params import SpecCreateParams as SpecCreateParams
from .spec_list_response import SpecListResponse as SpecListResponse
from .spec_update_params import SpecUpdateParams as SpecUpdateParams
from .run_create_response import RunCreateResponse as RunCreateResponse
from .run_status_response import RunStatusResponse as RunStatusResponse
from .run_update_response import RunUpdateResponse as RunUpdateResponse
from .spec_create_response import SpecCreateResponse as SpecCreateResponse
from .spec_update_response import SpecUpdateResponse as SpecUpdateResponse
from .analyze_create_params import AnalyzeCreateParams as AnalyzeCreateParams
from .dataset_list_response import DatasetListResponse as DatasetListResponse
from .dataset_update_params import DatasetUpdateParams as DatasetUpdateParams
from .run_retrieve_response import RunRetrieveResponse as RunRetrieveResponse
from .file_download_response import FileDownloadResponse as FileDownloadResponse
from .generate_create_params import GenerateCreateParams as GenerateCreateParams
from .spec_retrieve_response import SpecRetrieveResponse as SpecRetrieveResponse
from .analyze_create_response import AnalyzeCreateResponse as AnalyzeCreateResponse
from .dataset_update_response import DatasetUpdateResponse as DatasetUpdateResponse
from .chat_send_message_params import ChatSendMessageParams as ChatSendMessageParams
from .evaluation_create_params import EvaluationCreateParams as EvaluationCreateParams
from .evaluation_list_response import EvaluationListResponse as EvaluationListResponse
from .generate_create_response import GenerateCreateResponse as GenerateCreateResponse
from .chat_get_history_response import ChatGetHistoryResponse as ChatGetHistoryResponse
from .dataset_retrieve_response import DatasetRetrieveResponse as DatasetRetrieveResponse
from .file_get_content_response import FileGetContentResponse as FileGetContentResponse
from .chat_send_message_response import ChatSendMessageResponse as ChatSendMessageResponse
from .evaluation_create_response import EvaluationCreateResponse as EvaluationCreateResponse
from .red_team_run_list_response import RedTeamRunListResponse as RedTeamRunListResponse
from .analyze_get_status_response import AnalyzeGetStatusResponse as AnalyzeGetStatusResponse
from .dataset_list_files_response import DatasetListFilesResponse as DatasetListFilesResponse
from .human_label_update_response import HumanLabelUpdateResponse as HumanLabelUpdateResponse
from .red_team_spec_list_response import RedTeamSpecListResponse as RedTeamSpecListResponse
from .evaluation_retrieve_response import EvaluationRetrieveResponse as EvaluationRetrieveResponse
from .red_team_run_create_response import RedTeamRunCreateResponse as RedTeamRunCreateResponse
from .dataset_list_folders_response import DatasetListFoldersResponse as DatasetListFoldersResponse
from .human_label_retrieve_response import HumanLabelRetrieveResponse as HumanLabelRetrieveResponse
from .red_team_create_task_response import RedTeamCreateTaskResponse as RedTeamCreateTaskResponse
from .red_team_spec_create_response import RedTeamSpecCreateResponse as RedTeamSpecCreateResponse
from .red_team_spec_update_response import RedTeamSpecUpdateResponse as RedTeamSpecUpdateResponse
from .dataset_create_from_zip_params import DatasetCreateFromZipParams as DatasetCreateFromZipParams
from .red_team_run_retrieve_response import RedTeamRunRetrieveResponse as RedTeamRunRetrieveResponse
from .red_team_spec_retrieve_response import RedTeamSpecRetrieveResponse as RedTeamSpecRetrieveResponse
from .dataset_create_from_zip_response import DatasetCreateFromZipResponse as DatasetCreateFromZipResponse
from .dataset_create_with_files_params import DatasetCreateWithFilesParams as DatasetCreateWithFilesParams
from .generate_retrieve_status_response import GenerateRetrieveStatusResponse as GenerateRetrieveStatusResponse
from .red_team_retrieve_status_response import RedTeamRetrieveStatusResponse as RedTeamRetrieveStatusResponse
from .dataset_create_with_files_response import DatasetCreateWithFilesResponse as DatasetCreateWithFilesResponse
from .red_team_run_retrieve_status_response import RedTeamRunRetrieveStatusResponse as RedTeamRunRetrieveStatusResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .chat import (
    ChatResource,
    AsyncChatResource,
    ChatResourceWithRawResponse,
    AsyncChatResourceWithRawResponse,
    ChatResourceWithStreamingResponse,
    AsyncChatResourceWithStreamingResponse,
)
from .evaluations import (
    EvaluationsResource,
    AsyncEvaluationsResource,
    EvaluationsResourceWithRawResponse,
    AsyncEvaluationsResourceWithRawResponse,
    EvaluationsResourceWithStreamingResponse,
    AsyncEvaluationsResourceWithStreamingResponse,
)

__all__ = [
    "ChatResource",
    "AsyncChatResource",
    "ChatResourceWithRawResponse",
    "AsyncChatResourceWithRawResponse",
    "ChatResourceWithStreamingResponse",
    "AsyncChatResourceWithStreamingResponse",
    "EvaluationsResource",
    "AsyncEvaluationsResource",
    "EvaluationsResourceWithRawResponse",
    "AsyncEvaluationsResourceWithRawResponse",
    "EvaluationsResourceWithStreamingResponse",
    "AsyncEvaluationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.spec_version import SpecVersion
from ....types.dataframer.specs.version_list_response import VersionListResponse
from ....types.dataframer.specs.version_create_response import VersionCreateResponse
from ....types.dataframer.specs.version_update_response import VersionUpdateResponse

__all__ = ["VersionsResource", "AsyncVersionsResource"]


class VersionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return VersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return VersionsResourceWithStreamingResponse(self)

    def create(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionCreateResponse:
        """
        Create a new spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return self._post(
            f"/api/dataframer/specs/{spec_id}/versions/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionCreateResponse,
        )

    def retrieve(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecVersion:
        """
        Get a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return self._get(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecVersion,
        )

    def update(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionUpdateResponse:
        """
        Update a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return self._put(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionUpdateResponse,
        )

    def list(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionListResponse:
        """
        Get all versions for a specific spec

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return self._get(
            f"/api/dataframer/specs/{spec_id}/versions/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )

    def delete(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncVersionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncVersionsResourceWithStreamingResponse(self)

    async def create(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionCreateResponse:
        """
        Create a new spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return await self._post(
            f"/api/dataframer/specs/{spec_id}/versions/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionCreateResponse,
        )

    async def retrieve(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SpecVersion:
        """
        Get a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return await self._get(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SpecVersion,
        )

    async def update(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionUpdateResponse:
        """
        Update a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        return await self._put(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionUpdateResponse,
        )

    async def list(
        self,
        spec_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionListResponse:
        """
        Get all versions for a specific spec

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        return await self._get(
            f"/api/dataframer/specs/{spec_id}/versions/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )

    async def delete(
        self,
        version_id: str,
        *,
        spec_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a specific spec version

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not spec_id:
            raise ValueError(f"Expected a non-empty value for `spec_id` but received {spec_id!r}")
        if not version_id:
            raise ValueError(f"Expected a non-empty value for `version_id` but received {version_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/api/dataframer/specs/{spec_id}/versions/{version_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class VersionsResourceWithRawResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.create = to_raw_response_wrapper(
            versions.create,
        )
        self.retrieve = to_raw_response_wrapper(
            versions.retrieve,
        )
        self.update = to_raw_response_wrapper(
            versions.update,
        )
        self.list = to_raw_response_wrapper(
            versions.list,
        )
        self.delete = to_raw_response_wrapper(
            versions.delete,
        )


class AsyncVersionsResourceWithRawResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.create = async_to_raw_response_wrapper(
            versions.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            versions.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            versions.update,
        )
        self.list = async_to_raw_response_wrapper(
            versions.list,
        )
        self.delete = async_to_raw_response_wrapper(
            versions.delete,
        )


class VersionsResourceWithStreamingResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.create = to_streamed_response_wrapper(
            versions.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            versions.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            versions.update,
        )
        self.list = to_streamed_response_wrapper(
            versions.list,
        )
        self.delete = to_streamed_response_wrapper(
            versions.delete,
        )


class AsyncVersionsResourceWithStreamingResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.create = async_to_streamed_response_wrapper(
            versions.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            versions.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            versions.update,
        )
        self.list = async_to_streamed_response_wrapper(
            versions.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            versions.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["File"]


class File(BaseModel):
    file_name: str

    file_type: Literal["JSON", "JSONL", "CSV", "MD", "TXT", "PDF"]

    storage_uri: str

    id: Optional[str] = None

    bytes_size: Optional[int] = None

    created_at: Optional[datetime] = None

    datasets_id: Optional[str] = None

    file_type_display: Optional[str] = None

    folder_id: Optional[str] = None

    sha256: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from dataframer import Dataframer, AsyncDataframer
from tests.utils import assert_matches_type
from dataframer.types.dataframer.evaluations import (
    ChatGetHistoryResponse,
    ChatSendMessageResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestChat:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_history(self, client: Dataframer) -> None:
        chat = client.dataframer.evaluations.chat.get_history(
            "evaluation_id",
        )
        assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_history(self, client: Dataframer) -> None:
        response = client.dataframer.evaluations.chat.with_raw_response.get_history(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_history(self, client: Dataframer) -> None:
        with client.dataframer.evaluations.chat.with_streaming_response.get_history(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_history(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.dataframer.evaluations.chat.with_raw_response.get_history(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_send_message(self, client: Dataframer) -> None:
        chat = client.dataframer.evaluations.chat.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        )
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_send_message_with_all_params(self, client: Dataframer) -> None:
        chat = client.dataframer.evaluations.chat.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
            chat_model="anthropic/claude-sonnet-4-5",
        )
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_send_message(self, client: Dataframer) -> None:
        response = client.dataframer.evaluations.chat.with_raw_response.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = response.parse()
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_send_message(self, client: Dataframer) -> None:
        with client.dataframer.evaluations.chat.with_streaming_response.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = response.parse()
            assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_send_message(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            client.dataframer.evaluations.chat.with_raw_response.send_message(
                evaluation_id="",
                user_message="Why did some samples score lower than others?",
            )


class TestAsyncChat:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_history(self, async_client: AsyncDataframer) -> None:
        chat = await async_client.dataframer.evaluations.chat.get_history(
            "evaluation_id",
        )
        assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_history(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.evaluations.chat.with_raw_response.get_history(
            "evaluation_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_history(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.evaluations.chat.with_streaming_response.get_history(
            "evaluation_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert_matches_type(ChatGetHistoryResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_history(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.dataframer.evaluations.chat.with_raw_response.get_history(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_send_message(self, async_client: AsyncDataframer) -> None:
        chat = await async_client.dataframer.evaluations.chat.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        )
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_send_message_with_all_params(self, async_client: AsyncDataframer) -> None:
        chat = await async_client.dataframer.evaluations.chat.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
            chat_model="anthropic/claude-sonnet-4-5",
        )
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_send_message(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.evaluations.chat.with_raw_response.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        chat = await response.parse()
        assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_send_message(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.evaluations.chat.with_streaming_response.send_message(
            evaluation_id="evaluation_id",
            user_message="Why did some samples score lower than others?",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            chat = await response.parse()
            assert_matches_type(ChatSendMessageResponse, chat, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_send_message(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_id` but received ''"):
            await async_client.dataframer.evaluations.chat.with_raw_response.send_message(
                evaluation_id="",
                user_message="Why did some samples score lower than others?",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .file import File
from ..._models import BaseModel

__all__ = ["Folder"]


class Folder(BaseModel):
    name: str

    id: Optional[str] = None

    created_at: Optional[datetime] = None

    description: Optional[str] = None

    file_count: Optional[int] = None

    files: Optional[List[File]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from dataframer import Dataframer, AsyncDataframer
from tests.utils import assert_matches_type
from dataframer.types.dataframer import RedTeamCreateTaskResponse, RedTeamRetrieveStatusResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRedTeam:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_task(self, client: Dataframer) -> None:
        red_team = client.dataframer.red_team.create_task()
        assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_task(self, client: Dataframer) -> None:
        response = client.dataframer.red_team.with_raw_response.create_task()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team = response.parse()
        assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_task(self, client: Dataframer) -> None:
        with client.dataframer.red_team.with_streaming_response.create_task() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team = response.parse()
            assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_status(self, client: Dataframer) -> None:
        red_team = client.dataframer.red_team.retrieve_status(
            "task_id",
        )
        assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_status(self, client: Dataframer) -> None:
        response = client.dataframer.red_team.with_raw_response.retrieve_status(
            "task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team = response.parse()
        assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_status(self, client: Dataframer) -> None:
        with client.dataframer.red_team.with_streaming_response.retrieve_status(
            "task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team = response.parse()
            assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_status(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            client.dataframer.red_team.with_raw_response.retrieve_status(
                "",
            )


class TestAsyncRedTeam:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_task(self, async_client: AsyncDataframer) -> None:
        red_team = await async_client.dataframer.red_team.create_task()
        assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_task(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team.with_raw_response.create_task()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team = await response.parse()
        assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_task(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team.with_streaming_response.create_task() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team = await response.parse()
            assert_matches_type(RedTeamCreateTaskResponse, red_team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_status(self, async_client: AsyncDataframer) -> None:
        red_team = await async_client.dataframer.red_team.retrieve_status(
            "task_id",
        )
        assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_status(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team.with_raw_response.retrieve_status(
            "task_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team = await response.parse()
        assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_status(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team.with_streaming_response.retrieve_status(
            "task_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team = await response.parse()
            assert_matches_type(RedTeamRetrieveStatusResponse, red_team, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_status(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `task_id` but received ''"):
            await async_client.dataframer.red_team.with_raw_response.retrieve_status(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["GeneratedFileListResponse", "GeneratedFile"]


class GeneratedFile(BaseModel):
    id: Optional[str] = None

    content: Optional[str] = None

    evaluation_model: Optional[str] = None

    generation_model: Optional[str] = None

    iterations: Optional[int] = None

    name: Optional[str] = None

    path: Optional[str] = None

    s3_key: Optional[str] = None

    size: Optional[int] = None

    status: Optional[str] = None

    status_details: Optional[str] = FieldInfo(alias="statusDetails", default=None)

    termination_reason: Optional[str] = None

    type: Optional[str] = None

    uploaded_at: Optional[str] = FieldInfo(alias="uploadedAt", default=None)

    workflow_id: Optional[str] = None


class GeneratedFileListResponse(BaseModel):
    generated_files: List[GeneratedFile]
    """List of generated files"""

    run_id: str
    """ID of the run"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.dataframer import generate_create_params
from ...types.dataframer.generate_create_response import GenerateCreateResponse
from ...types.dataframer.generate_retrieve_status_response import GenerateRetrieveStatusResponse

__all__ = ["GenerateResource", "AsyncGenerateResource"]


class GenerateResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GenerateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return GenerateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GenerateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return GenerateResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        generation_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini", "o1", "o1-mini"],
        number_of_samples: int,
        spec_id: str,
        enable_revisions: bool | Omit = omit,
        evaluation_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        evaluation_thinking_budget: int | Omit = omit,
        generation_thinking_budget: int | Omit = omit,
        max_iterations: int | Omit = omit,
        max_revision_cycles: int | Omit = omit,
        num_examples_in_prompt: int | Omit = omit,
        outline_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        outline_thinking_budget: int | Omit = omit,
        revision_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        revision_thinking_budget: int | Omit = omit,
        sample_type: Literal["short", "long"] | Omit = omit,
        spec_version_id: str | Omit = omit,
        staged_generation: bool | Omit = omit,
        use_historical_feedback: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GenerateCreateResponse:
        """
        Generate synthetic data samples based on a spec using AI models.

        The generation process:

        1. Selects the spec version (specified version or latest)
        2. Submits generation job to external service
        3. Creates a Run record to track progress
        4. Returns immediately with run_id for status polling

        Supports two sample types:

        - **short**: Quick generation with optional feedback iterations
        - **long**: Multi-stage generation with outline, draft, and revision cycles

        Args:
          generation_model: AI model to use for generation

          number_of_samples: Number of samples to generate

          spec_id: ID of the spec to use for generation

          enable_revisions: Enable revision cycles

          evaluation_model: AI model for evaluation (optional)

          evaluation_thinking_budget: Thinking budget for evaluation model (tokens, short samples)

          generation_thinking_budget: Thinking budget for generation model (tokens)

          max_iterations: Max feedback iterations (short samples only)

          max_revision_cycles: Max revision cycles (long samples only)

          num_examples_in_prompt: Number of examples to include in prompt (short samples only)

          outline_model: AI model for outline generation (long samples only)

          outline_thinking_budget: Thinking budget for outline model (tokens, long samples)

          revision_model: AI model for revisions (long samples only)

          revision_thinking_budget: Thinking budget for revision model (tokens, long samples)

          sample_type: Type of samples to generate

          spec_version_id: Specific version ID to use (optional, defaults to latest version)

          staged_generation: Use staged generation approach (short samples only)

          use_historical_feedback: Use historical feedback (short samples only)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/dataframer/generate/",
            body=maybe_transform(
                {
                    "generation_model": generation_model,
                    "number_of_samples": number_of_samples,
                    "spec_id": spec_id,
                    "enable_revisions": enable_revisions,
                    "evaluation_model": evaluation_model,
                    "evaluation_thinking_budget": evaluation_thinking_budget,
                    "generation_thinking_budget": generation_thinking_budget,
                    "max_iterations": max_iterations,
                    "max_revision_cycles": max_revision_cycles,
                    "num_examples_in_prompt": num_examples_in_prompt,
                    "outline_model": outline_model,
                    "outline_thinking_budget": outline_thinking_budget,
                    "revision_model": revision_model,
                    "revision_thinking_budget": revision_thinking_budget,
                    "sample_type": sample_type,
                    "spec_version_id": spec_version_id,
                    "staged_generation": staged_generation,
                    "use_historical_feedback": use_historical_feedback,
                },
                generate_create_params.GenerateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenerateCreateResponse,
        )

    def retrieve_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GenerateRetrieveStatusResponse:
        """
        Get generation status from external service

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return self._get(
            f"/api/dataframer/generate/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenerateRetrieveStatusResponse,
        )


class AsyncGenerateResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGenerateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncGenerateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGenerateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aimonlabs/dataframer-python-sdk#with_streaming_response
        """
        return AsyncGenerateResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        generation_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini", "o1", "o1-mini"],
        number_of_samples: int,
        spec_id: str,
        enable_revisions: bool | Omit = omit,
        evaluation_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        evaluation_thinking_budget: int | Omit = omit,
        generation_thinking_budget: int | Omit = omit,
        max_iterations: int | Omit = omit,
        max_revision_cycles: int | Omit = omit,
        num_examples_in_prompt: int | Omit = omit,
        outline_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        outline_thinking_budget: int | Omit = omit,
        revision_model: Literal["claude-3-5-sonnet-v2@20241022", "gpt-4o", "gpt-4o-mini"] | Omit = omit,
        revision_thinking_budget: int | Omit = omit,
        sample_type: Literal["short", "long"] | Omit = omit,
        spec_version_id: str | Omit = omit,
        staged_generation: bool | Omit = omit,
        use_historical_feedback: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GenerateCreateResponse:
        """
        Generate synthetic data samples based on a spec using AI models.

        The generation process:

        1. Selects the spec version (specified version or latest)
        2. Submits generation job to external service
        3. Creates a Run record to track progress
        4. Returns immediately with run_id for status polling

        Supports two sample types:

        - **short**: Quick generation with optional feedback iterations
        - **long**: Multi-stage generation with outline, draft, and revision cycles

        Args:
          generation_model: AI model to use for generation

          number_of_samples: Number of samples to generate

          spec_id: ID of the spec to use for generation

          enable_revisions: Enable revision cycles

          evaluation_model: AI model for evaluation (optional)

          evaluation_thinking_budget: Thinking budget for evaluation model (tokens, short samples)

          generation_thinking_budget: Thinking budget for generation model (tokens)

          max_iterations: Max feedback iterations (short samples only)

          max_revision_cycles: Max revision cycles (long samples only)

          num_examples_in_prompt: Number of examples to include in prompt (short samples only)

          outline_model: AI model for outline generation (long samples only)

          outline_thinking_budget: Thinking budget for outline model (tokens, long samples)

          revision_model: AI model for revisions (long samples only)

          revision_thinking_budget: Thinking budget for revision model (tokens, long samples)

          sample_type: Type of samples to generate

          spec_version_id: Specific version ID to use (optional, defaults to latest version)

          staged_generation: Use staged generation approach (short samples only)

          use_historical_feedback: Use historical feedback (short samples only)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/dataframer/generate/",
            body=await async_maybe_transform(
                {
                    "generation_model": generation_model,
                    "number_of_samples": number_of_samples,
                    "spec_id": spec_id,
                    "enable_revisions": enable_revisions,
                    "evaluation_model": evaluation_model,
                    "evaluation_thinking_budget": evaluation_thinking_budget,
                    "generation_thinking_budget": generation_thinking_budget,
                    "max_iterations": max_iterations,
                    "max_revision_cycles": max_revision_cycles,
                    "num_examples_in_prompt": num_examples_in_prompt,
                    "outline_model": outline_model,
                    "outline_thinking_budget": outline_thinking_budget,
                    "revision_model": revision_model,
                    "revision_thinking_budget": revision_thinking_budget,
                    "sample_type": sample_type,
                    "spec_version_id": spec_version_id,
                    "staged_generation": staged_generation,
                    "use_historical_feedback": use_historical_feedback,
                },
                generate_create_params.GenerateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenerateCreateResponse,
        )

    async def retrieve_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GenerateRetrieveStatusResponse:
        """
        Get generation status from external service

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        return await self._get(
            f"/api/dataframer/generate/status/{task_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GenerateRetrieveStatusResponse,
        )


class GenerateResourceWithRawResponse:
    def __init__(self, generate: GenerateResource) -> None:
        self._generate = generate

        self.create = to_raw_response_wrapper(
            generate.create,
        )
        self.retrieve_status = to_raw_response_wrapper(
            generate.retrieve_status,
        )


class AsyncGenerateResourceWithRawResponse:
    def __init__(self, generate: AsyncGenerateResource) -> None:
        self._generate = generate

        self.create = async_to_raw_response_wrapper(
            generate.create,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            generate.retrieve_status,
        )


class GenerateResourceWithStreamingResponse:
    def __init__(self, generate: GenerateResource) -> None:
        self._generate = generate

        self.create = to_streamed_response_wrapper(
            generate.create,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            generate.retrieve_status,
        )


class AsyncGenerateResourceWithStreamingResponse:
    def __init__(self, generate: AsyncGenerateResource) -> None:
        self._generate = generate

        self.create = async_to_streamed_response_wrapper(
            generate.create,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            generate.retrieve_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from dataframer import Dataframer, AsyncDataframer
from tests.utils import assert_matches_type
from dataframer.types import (
    DataframerListModelsResponse,
    DataframerCheckHealthResponse,
    DataframerListHistoricalRunsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDataframer:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_check_health(self, client: Dataframer) -> None:
        dataframer = client.dataframer.check_health()
        assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_check_health(self, client: Dataframer) -> None:
        response = client.dataframer.with_raw_response.check_health()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = response.parse()
        assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_check_health(self, client: Dataframer) -> None:
        with client.dataframer.with_streaming_response.check_health() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = response.parse()
            assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_historical_runs(self, client: Dataframer) -> None:
        dataframer = client.dataframer.list_historical_runs()
        assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_historical_runs(self, client: Dataframer) -> None:
        response = client.dataframer.with_raw_response.list_historical_runs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = response.parse()
        assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_historical_runs(self, client: Dataframer) -> None:
        with client.dataframer.with_streaming_response.list_historical_runs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = response.parse()
            assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_models(self, client: Dataframer) -> None:
        dataframer = client.dataframer.list_models()
        assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_models(self, client: Dataframer) -> None:
        response = client.dataframer.with_raw_response.list_models()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = response.parse()
        assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_models(self, client: Dataframer) -> None:
        with client.dataframer.with_streaming_response.list_models() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = response.parse()
            assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDataframer:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_check_health(self, async_client: AsyncDataframer) -> None:
        dataframer = await async_client.dataframer.check_health()
        assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_check_health(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.with_raw_response.check_health()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = await response.parse()
        assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_check_health(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.with_streaming_response.check_health() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = await response.parse()
            assert_matches_type(DataframerCheckHealthResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_historical_runs(self, async_client: AsyncDataframer) -> None:
        dataframer = await async_client.dataframer.list_historical_runs()
        assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_historical_runs(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.with_raw_response.list_historical_runs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = await response.parse()
        assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_historical_runs(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.with_streaming_response.list_historical_runs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = await response.parse()
            assert_matches_type(DataframerListHistoricalRunsResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_models(self, async_client: AsyncDataframer) -> None:
        dataframer = await async_client.dataframer.list_models()
        assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_models(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.with_raw_response.list_models()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        dataframer = await response.parse()
        assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_models(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.with_streaming_response.list_models() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            dataframer = await response.parse()
            assert_matches_type(DataframerListModelsResponse, dataframer, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["ChatSendMessageParams"]


class ChatSendMessageParams(TypedDict, total=False):
    evaluation_id: Required[str]
    """ID of the evaluation to chat about"""

    user_message: Required[str]
    """Your question or message about the evaluation results"""

    chat_model: Literal[
        "anthropic/claude-sonnet-4-5", "anthropic/claude-sonnet-4-5-thinking", "anthropic/claude-haiku-4-5"
    ]
    """AI model to use for chat (optional)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from dataframer import Dataframer, AsyncDataframer
from tests.utils import assert_matches_type
from dataframer.types.dataframer import (
    RedTeamSpecListResponse,
    RedTeamSpecCreateResponse,
    RedTeamSpecUpdateResponse,
    RedTeamSpecRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRedTeamSpecs:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Dataframer) -> None:
        red_team_spec = client.dataframer.red_team_specs.create()
        assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Dataframer) -> None:
        response = client.dataframer.red_team_specs.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = response.parse()
        assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Dataframer) -> None:
        with client.dataframer.red_team_specs.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = response.parse()
            assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Dataframer) -> None:
        red_team_spec = client.dataframer.red_team_specs.retrieve(
            "spec_id",
        )
        assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Dataframer) -> None:
        response = client.dataframer.red_team_specs.with_raw_response.retrieve(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = response.parse()
        assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Dataframer) -> None:
        with client.dataframer.red_team_specs.with_streaming_response.retrieve(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = response.parse()
            assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            client.dataframer.red_team_specs.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Dataframer) -> None:
        red_team_spec = client.dataframer.red_team_specs.update(
            "spec_id",
        )
        assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Dataframer) -> None:
        response = client.dataframer.red_team_specs.with_raw_response.update(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = response.parse()
        assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Dataframer) -> None:
        with client.dataframer.red_team_specs.with_streaming_response.update(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = response.parse()
            assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            client.dataframer.red_team_specs.with_raw_response.update(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Dataframer) -> None:
        red_team_spec = client.dataframer.red_team_specs.list()
        assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Dataframer) -> None:
        response = client.dataframer.red_team_specs.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = response.parse()
        assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Dataframer) -> None:
        with client.dataframer.red_team_specs.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = response.parse()
            assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Dataframer) -> None:
        red_team_spec = client.dataframer.red_team_specs.delete(
            "spec_id",
        )
        assert red_team_spec is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Dataframer) -> None:
        response = client.dataframer.red_team_specs.with_raw_response.delete(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = response.parse()
        assert red_team_spec is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Dataframer) -> None:
        with client.dataframer.red_team_specs.with_streaming_response.delete(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = response.parse()
            assert red_team_spec is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Dataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            client.dataframer.red_team_specs.with_raw_response.delete(
                "",
            )


class TestAsyncRedTeamSpecs:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncDataframer) -> None:
        red_team_spec = await async_client.dataframer.red_team_specs.create()
        assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team_specs.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = await response.parse()
        assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team_specs.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = await response.parse()
            assert_matches_type(RedTeamSpecCreateResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncDataframer) -> None:
        red_team_spec = await async_client.dataframer.red_team_specs.retrieve(
            "spec_id",
        )
        assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team_specs.with_raw_response.retrieve(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = await response.parse()
        assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team_specs.with_streaming_response.retrieve(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = await response.parse()
            assert_matches_type(RedTeamSpecRetrieveResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            await async_client.dataframer.red_team_specs.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncDataframer) -> None:
        red_team_spec = await async_client.dataframer.red_team_specs.update(
            "spec_id",
        )
        assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team_specs.with_raw_response.update(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = await response.parse()
        assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team_specs.with_streaming_response.update(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = await response.parse()
            assert_matches_type(RedTeamSpecUpdateResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            await async_client.dataframer.red_team_specs.with_raw_response.update(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncDataframer) -> None:
        red_team_spec = await async_client.dataframer.red_team_specs.list()
        assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team_specs.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = await response.parse()
        assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team_specs.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = await response.parse()
            assert_matches_type(RedTeamSpecListResponse, red_team_spec, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncDataframer) -> None:
        red_team_spec = await async_client.dataframer.red_team_specs.delete(
            "spec_id",
        )
        assert red_team_spec is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDataframer) -> None:
        response = await async_client.dataframer.red_team_specs.with_raw_response.delete(
            "spec_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        red_team_spec = await response.parse()
        assert red_team_spec is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDataframer) -> None:
        async with async_client.dataframer.red_team_specs.with_streaming_response.delete(
            "spec_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            red_team_spec = await response.parse()
            assert red_team_spec is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncDataframer) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `spec_id` but received ''"):
            await async_client.dataframer.red_team_specs.with_raw_response.delete(
                "",
            )
